@@ -9,26 +9,26 @@
 #endif
 
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 void driver_init() {
   mysql_library_init(0, NULL, NULL);
 }
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 void driver_done() {
   mysql_library_end();
 }
 
-// [[Rcpp::export]]
-IntegerVector version() {
+[[cpp11::register]]
+cpp11::integers version() {
   return
-    IntegerVector::create(
-      _[SERVER_VERSION] = MYSQL_VERSION_ID,
-      _[mysql_get_client_info()] = mysql_get_client_version()
-    );
+    cpp11::writable::integers({
+      cpp11::named_arg(SERVER_VERSION) = MYSQL_VERSION_ID,
+      cpp11::named_arg(mysql_get_client_info()) = mysql_get_client_version()
+    });
 }
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 void init_logging(const std::string& log_level) {
   plog::init_r(log_level);
 }
