@@ -1,5 +1,3 @@
-context("dbWriteTable")
-
 # test_that("can't override existing table with default options", {
 #   con <- mariadbDefault()
 #
@@ -87,7 +85,11 @@ test_that("writing and reading JSON (#127)", {
   x <- data.frame(col1 = "[1,2,3]", stringsAsFactors = FALSE)
 
   dbWriteTable(con, "t1", x, field.types = c(col1 = "json"), overwrite = TRUE, temporary = TRUE)
-  dbReadTable(con, "t1")
 
-  expect_equal(dbReadTable(con, "t1"), x)
+  suppressWarnings(d <- dbReadTable(con, "t1"))
+
+  # MySQL 8 returns "[1, 2, 3]", while MariaDB returns "[1,2,3]"
+  d$col1 <- gsub('\\s', '', d$col1)
+
+  expect_equal(d, x)
 })
